Client

Struct Client 

pub struct Client { /* private fields */ }

Implementations

Source

impl Client

pub fn new(address: &str, port: u16) -> Result<Self, Error>

Create a new electrum client.

Arguments
  • address - url/ip of the electrum server as String
  • port - port of the electrum server
pub fn new_local(address: &str, port: u16) -> Result<Self, Error>

Create a new local electrum client: SSL certificate validation id disabled in order to be used with self-signed certificates.

Arguments
  • address - url/ip of the electrum server as String
  • port - port of the electrum server
pub fn listen<RQ, RS>(self) -> (Sender<RQ>, Receiver<RS>)
where RQ: Into<CoinRequest> + Debug + Send + 'static, RS: From<CoinResponse> + Debug + Send + 'static,

pub fn get_tx(&mut self, txid: Txid) -> Result<Transaction, Error>

Try to get a transaction by its txid

Errors

This function will return an error if:

  • fail to send the request
  • parsing response fails
  • the response is not of expected type
  • the transaction does not exists
pub fn get_coins_at( &mut self, script: &Script, ) -> Result<(Vec<(TxOut, OutPoint)>, HashMap<Txid, Transaction>), Error>

Get coins that pay to the given spk and their related transaction. This method will make several calls to the electrum server:

  • it will first request a list of all transactions txid that have an output paying to the spk.
  • it will then fetch all txs, store them and extract all the coins that pay to the given spk.
  • it will return a list of (TxOut, OutPoint) and a map of transactions.
Errors

This function will return an error if:

  • a call to the electrum server fail
pub fn get_coins_tx_at(&mut self, script: &Script) -> Result<Vec<Txid>, Error>

Get a list of txid of all transaction that have an output paying to the given spk

Errors

This function will return an error if:

  • fail sending the request
  • receive a wrong response
pub fn broadcast(&mut self, tx: &Transaction) -> Result<(), Error>

Broadcast the given transaction.

Errors

This function will return an error if:

  • fail to send the request
  • get a wrong response
pub fn url(&self) -> String

Returns the URL of the electrum client.

Returns

A String containing the URL of the electrum server.

pub fn port(&self) -> u16

Returns the port of the electrum client.

Returns

A u16 containing the port of the electrum server.